@@ -1,3 +1,4 @@
+import glob
 import json
 import os
 
@@ -127,7 +128,8 @@ def test_scramble_cont_job(client, metadata_client):
         'reader_name': 'CsvReader',
         'writer_name': 'CsvWriter',
         'clean_start': 'false',
-        'cont': False
+        'cont': False,
+        'force_overwrite': 'true'
     }
     param_string = _make_param_string(job_params)
     response = client.post(
@@ -289,3 +291,63 @@ def test_clean(client, job_params, metadata, output):
     assert report['served'] == 0
     assert report['received'] == n_received
 
+
+@pytest.mark.local
+@pytest.mark.parametrize(
+    'output', [True, False]
+)
+def test_purge(client, job_params, metadata, output):
+    n_served = 10
+    n_received = 5
+    param_string = _make_param_string(job_params)
+    output_file_path = metadata["output_file_path"]
+    for i in range(10):
+        metadata["output_file_path"] = f'{output_file_path}.{i}'
+        client.post(
+            f'/scramble?{param_string}',
+            json=metadata
+        )
+        items = json.loads(
+            client.post(f'/serve?job_name={TEST_JOB_NAME}&'
+                        f'batch_size={n_served}').text
+        )
+        response = client.post(
+            f'/receive?job_name={TEST_JOB_NAME}&overwrite=false',
+            json=items[:n_received]
+        )
+        assert response.status_code == 200, response.text
+    response = client.get(f'/purge?output={output}')
+    assert response.status_code == 200, response.text
+    for fp in glob.glob(f'{output_file_path}*'):
+        assert (not os.path.isfile(fp)) is output
+        response = client.get(f'/report?job_name={TEST_JOB_NAME}')
+        assert response.status_code == 200, response.text
+        report = json.loads(response.text)
+        assert report == {}
+
+
+@pytest.mark.local
+def test_output_registry(client, job_params, metadata):
+    job_params['force_overwrite'] = False
+    param_string = _make_param_string(job_params)
+    client.post(
+        f'/scramble?{param_string}',
+        json=metadata
+    )
+    response = client.get(f'/report?job_name={TEST_JOB_NAME}')
+    assert response.status_code == 200, response.text
+    job_params['job_name'] = 'new_original_job_12342345345'
+    param_string = _make_param_string(job_params)
+    response = client.post(
+        f'/scramble?{param_string}',
+        json=metadata
+    )
+    assert response.status_code == 400, 'Output registry did not block creating a new job'
+    client.get(f'/purge')
+    job_params['job_name'] = 'new_original_job_98693458'
+    param_string = _make_param_string(job_params)
+    response = client.post(
+        f'/scramble?{param_string}',
+        json=metadata
+    )
+    assert response.status_code == 200, response.text
